Camarilla Threat Rome, Italy March 2nd 2003 14 players Marco La Valle "Mr. Majestic" A horde of small cap vampires with PRE relentlessly bleed and vote, taking multiple actions in the same turn. Charming lobby, awe and bewitching orations provide huge amount of votes, and voter captivations replenish your vampires, so allowing unlimited use of superior Majesty. Expect everybody at the table to turn against you: which is good, since you will cycle even faster through your library! This deck will be completely shut down by Atonement, so use your Hostile Takeover judiciously (a second one will be necessary, when this list will be made public). Crypt (12 cards, min=5, max=16, avg=2.67) ----------------------------------------- 2x Gideon Fontaine 3 PRE Ventrue:1 1x Rake 6 PRE aus cel pot prince Brujah:1 1x Violette Prentiss 4 PRE dom Ventrue:1 1x Itzahk Levine 3 cel pre Ventrue:2 1x Roland Loussarian 3 for pre Ventrue:1 1x Uma Hatch 3 cel pre Brujah:1 1x Delilah Easton 2 pre Toreador:1 1x Frederick the Weak 2 pre Brujah antitribu:2 1x Angela Decker 1 pre Pander:2 1x Antoinette DuChamp 1 cel pre Caitiff:2 1x Igo the Hungry 1 pre pro Caitiff:1 Library (90 cards) Master (21) 1x Barrens, The 3x Blood Doll 1x Dreams of the Sphinx 1x Elder Library 1x Elysium: The Arboretum 1x Fragment of the Book of Nod 1x Hostile Takeover 1x Parthenon, The 1x Powerbase: Montreal 7x Presence 1x Ventrue Headquarters 2x Visit from the Capuchin Action (4) 4x Charming Lobby Political Action (27) 2x Disputed Territory 1x Dramatic Upheaval 9x Kine Resources Contested 4x Parity Shift 1x Praxis Seizure: Amsterdam 1x Praxis Seizure: Barcelona 1x Praxis Seizure: Boston 1x Praxis Seizure: Brussels 1x Praxis Seizure: Cleveland 1x Praxis Seizure: Geneva 1x Praxis Seizure: Glasgow 1x Praxis Seizure: Monaco 1x Praxis Seizure: Stockholm 2x Rumors of Gehenna Action Modifier (20) 3x Awe 7x Bewitching Oration 10x Voter Captivation Combat (18) 18x Majesty